@@ -2,12 +2,14 @@
 	MIT License http://www.opensource.org/licenses/mit-license.php
 	Author Tobias Koppers @sokra
 */
+"use strict";
+
 module.exports = function getInnerRequest(resolver, request) {
 	if(typeof request.__innerRequest === "string" &&
 		request.__innerRequest_request === request.request &&
 		request.__innerRequest_relativePath === request.relativePath)
 		return request.__innerRequest;
-	var innerRequest;
+	let innerRequest;
 	if(request.request) {
 		innerRequest = request.request;
 		if(/^\.\.?\//.test(innerRequest) && request.relativePath) {
